@@ -1,5 +1,5 @@
 package Net::SPID::SAML;
-$Net::SPID::SAML::VERSION = '0.11';
+$Net::SPID::SAML::VERSION = '0.12';
 use Moo;
 
 use Carp;
@@ -208,7 +208,7 @@ Net::SPID::SAML
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -264,7 +264,7 @@ The preferred way to instantiate this class is to call C<Net::SPID->new(protocol
 
 =item I<sp_cert_file>
 
-(Required.) The absolute of relative file path to our certificate file.
+(Required.) The absolute or relative file path to our certificate file.
 
 =item I<sp_acs_url>
 
